@@ -1,16 +1,17 @@
-# Copyright Louis Paternault 2014-2016
+# Copyright Louis Paternault 2014-2021
+#
 # This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>. 1
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 """Errors and exceptions"""
 
@@ -30,4 +31,4 @@ class CouldNotParse(PdfautonupError):
     """Could not parse string as a paper size."""
 
     def __str__(self):
-        return "Could not parse paper size '{}'.".format(self.message)
+        return f"Could not parse paper size '{self.message}'."
